'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.nextYear = nextYear;
exports.nextMonth = nextMonth;
exports.nextHour = nextHour;
exports.updateQueryStringParameter = updateQueryStringParameter;
exports.makeUUID4 = makeUUID4;
exports.hasprop = hasprop;
var BLOCKSTACK_HANDLER = exports.BLOCKSTACK_HANDLER = 'blockstack';
/**
 * Time
 */

function nextYear() {
  return new Date(new Date().setFullYear(new Date().getFullYear() + 1));
}

function nextMonth() {
  return new Date(new Date().setMonth(new Date().getMonth() + 1));
}

function nextHour() {
  return new Date(new Date().setHours(new Date().getHours() + 1));
}

/**
 * Query Strings
 */

function updateQueryStringParameter(uri, key, value) {
  var re = new RegExp("([?&])" + key + "=.*?(&|$)", "i");
  var separator = uri.indexOf('?') !== -1 ? "&" : "?";
  if (uri.match(re)) {
    return uri.replace(re, '$1' + key + "=" + value + '$2');
  } else {
    return uri + separator + key + "=" + value;
  }
}

/**
 * UUIDs
 */

function makeUUID4() {
  var d = new Date().getTime();
  if (typeof performance !== 'undefined' && typeof performance.now === 'function') {
    d += performance.now(); //use high-precision timer if available
  }
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
    var r = (d + Math.random() * 16) % 16 | 0;
    d = Math.floor(d / 16);
    return (c === 'x' ? r : r & 0x3 | 0x8).toString(16);
  });
}

/**
 * Properties
 */

/**
  * Determines whether a given object has a certain nested property
  * @param {Object} obj - the object to be checked
  * @param {String} path - the nested pathway to check
  *
  * Author: Miguel Mota <hello@miguelmota.com> (http://www.miguelmota.com/)
  */
function hasprop(obj, path) {
  if (arguments.length === 1 && ((typeof obj === 'undefined' ? 'undefined' : _typeof(obj)) === 'object' || obj instanceof Object)) {
    return function (path) {
      return hasprop(obj, path);
    };
  }

  if (!((typeof obj === 'undefined' ? 'undefined' : _typeof(obj)) === 'object' || obj instanceof Object) || obj === null) {
    return false;
  }

  var props = [];

  if (Array.isArray(path)) {
    props = path;
  } else {
    if (!(typeof path === 'string' || path instanceof String)) {
      return false;
    }

    props = (path.match(/(\[(.*?)\]|[0-9a-zA-Z_$]+)/gi) || props).map(function (match) {
      return match.replace(/[\[\]]/gi, '');
    });
  }

  var size = props.length;
  var last = props[size - 1];
  var head = obj;

  for (var i = 0; i < size; i += 1) {
    if (typeof head[props[i]] === 'undefined' || head[props[i]] === null) {
      return false;
    }
    head = head[props[i]];
    if (typeof head !== 'undefined') {
      if (props[i] === last && i === size - 1) {
        return true;
      }
    }
  }

  return false;
}